@@ -1,3 +1,7 @@
+##
+## MANUAL TOUR WORK HORSES -----
+##
+
 #' Create a manipulation space to rotate the manip variable in.
 #'
 #' Typically called by `manual_tour()`. Creates a (p, d) orthonormal matrix,
@@ -13,24 +17,35 @@
 #' @import tourr
 #' @export
 #' @examples
-#' flea_std <- tourr::rescale(tourr::flea[,1:6])
+#' ## Setup
+#' dat_std <- scale_sd(wine[, 2:14])
+#' bas <- basis_pca(dat_std)
+#' mv <- manip_var_pca(bas)
 #' 
-#' rb <- tourr::basis_random(n = ncol(flea_std))
-#' create_manip_space(basis = rb, manip_var = 4)
-create_manip_space <- function(basis, manip_var) {
-  if (!is.matrix(basis)) as.matrix(basis)
+#' create_manip_space(basis = bas, manip_var = mv)
+create_manip_space <- function(basis, manip_var){
+  ## Assumptions
+  basis <- as.matrix(basis)
+  if(spinifex::is_orthonormal(basis) == FALSE){
+    warning("Basis was not orthonormal. Coereced to othronormal with tourr::orthonormalise(basis).")
+    basis <- tourr::orthonormalise(basis)
+  }
+  if(ncol(basis) >= 3){
+    warning(paste0("Basis of d = ", ncol(basis),
+                   " used. Spinifex is only implemented for d = 2 at the momment. The basis as been truncated to 2 dimensions."))
+    basis <- basis[, 1L:2L]
+  }
   
+  ## Add manip variable and orthonormalize
   manip_space <- cbind(basis, rep(0L, len = nrow(basis)))
-  manip_space[manip_var, 3L] <- 1L
+  manip_space[manip_var, ncol(manip_space)] <- 1L
   manip_space <- tourr::orthonormalise(manip_space)
-
-  ## Checks and formating
-  stopifnot(spinifex::is_orthonormal(manip_space))
-  if (is.null(colnames(basis)) == FALSE)
-    colnames(manip_space) <- colnames(basis)
-  if (is.null(rownames(manip_space)) == FALSE)
-    rownames(manip_space) <- rownames(basis)
+  colnames(manip_space) <-
+    c(paste0("P", 1L:(ncol(manip_space) - 1L)), "manip_sp")
+  rownames(manip_space) <-
+    paste0("V", 1L:nrow(manip_space))
   
+  ## Return
   manip_space
 }
 
@@ -39,28 +54,38 @@ create_manip_space <- function(basis, manip_var) {
 #' Performs a rotation on the manipulation space of the given manip var.
 #'
 #' A specific R3 rotation of the manipulation space for a 2D tour.
-#' Typically called by `manual_tour()`. The first 2 columns are x and y in 
-#' the projection plane. The 3rd column extends "in the z-direction" orthogonal 
+#' Typically called by `manual_tour()`. The first 2 columns are x and y in
+#' the projection plane. The 3rd column extends "in the z-direction" orthogonal
 #' to the projection plane.
 #'
 #' @param manip_space A (p, d+1) dim matrix (manipulation space) to be rotated.
 #' @param theta Angle (radians) of "in-projection-plane" rotation (ie. on xy-
 #' of the projection). Typically set by the manip_type argument in `proj_data()`.
 #' @param phi Angle (radians) of "out-of-projection-plane" rotation (ie. into
-#' the z-direction of the manipulation space. Effectively changes the norm 
+#' the z-direction of the manipulation space. Effectively changes the norm
 #' of the manip_var in the projection plane.
-#' @return A (p, d+1) orthonormal matrix of the rotated (manipulation) space. 
-#' The first 2 columns are x and y in the projection plane. The 3rd column 
+#' @return A (p, d+1) orthonormal matrix of the rotated (manipulation) space.
+#' The first 2 columns are x and y in the projection plane. The 3rd column
 #' extends "in the z-direction" orthogonal to the projection plane.
 #' @export
 #' @examples
-#' flea_std <- tourr::rescale(tourr::flea[,1:6])
-#' rb  <- tourr::basis_random(n = ncol(flea_std))
-#' msp <- create_manip_space(basis = rb, manip_var = 4)
+#' ## Setup
+#' dat_std <- scale_sd(wine[, 2:14])
+#' bas <- basis_pca(dat_std)
+#' mv <- manip_var_pca(bas)
+#' msp <- create_manip_space(basis = bas, manip_var = mv)
 #' 
-#' rotate_manip_space(msp, theta = runif(1, max = 2 * pi), 
-#'                    phi = runif(1, max = 2 * pi) )
+#' rotate_manip_space(msp, theta = runif(1, max = 2 * pi),
+#'                    phi = runif(1, max = 2 * pi))
 rotate_manip_space <- function(manip_space, theta, phi) {
+  ## Assumptions
+  manip_space <- as.matrix(manip_space)
+  if(spinifex::is_orthonormal(manip_space) == FALSE){
+    warning("manip_space was not orthonormal. Coereced to othronormal with tourr::orthonormalise(manip_space).")
+    manip_space <- tourr::orthonormalise(manip_space)
+  }
+  
+  ## Initalize
   s_theta <- sin(theta)
   c_theta <- cos(theta)
   s_phi   <- sin(phi)
@@ -79,15 +104,7 @@ rotate_manip_space <- function(manip_space, theta, phi) {
                nrow = 3L, ncol = 3L, byrow = TRUE)
   rotated_space <- manip_space %*% R3
   
-  ## Checks and formating
-  stopifnot(spinifex::is_orthonormal(rotated_space))
-  if (is.null(colnames(manip_space)) == FALSE) {
-    colnames(rotated_space) <- colnames(manip_space)
-  } else {colnames(rotated_space) <- paste0("proj_", 1L:ncol(rotated_space))}
-  if (is.null(rownames(manip_space)) == FALSE) {
-    rownames(rotated_space) <- rownames(manip_space)
-  } else {rownames(rotated_space) <- paste0("var_", 1L:nrow(rotated_space))}
-  
+  ## Return 
   rotated_space
 }
 
@@ -121,66 +138,120 @@ rotate_manip_space <- function(manip_space, theta, phi) {
 #' phi_start, `phi_min`, `phi_max`, and back to phi_start.
 #' @export
 #' @examples
-#' flea_std <- tourr::rescale(tourr::flea[, 1:6])
-#' rb <- tourr::basis_random(n = ncol(flea_std))
+#' ## Setup
+#' dat_std <- scale_sd(wine[, 2:14])
+#' clas <- wine$Type
+#' bas <- basis_pca(dat_std)
+#' mv <- manip_var_pca(dat_std)
 #' 
-#' manual_tour(basis = rb, manip_var = 4)
+#' ## Required arguments
+#' manual_tour(basis = bas, manip_var = mv)
 #' 
-#' manual_tour(basis = rb, manip_var = 6, 
-#'             theta = pi / 2, phi_min = pi / 16, phi_max = pi, angle = .1)
-manual_tour <- function(basis   = NULL,
+#' ## Full arguments
+#' manual_tour(basis = bas, manip_var = mv,
+#'             theta = pi / 2, phi_min = pi / 16, phi_max = pi, angle = .8)
+manual_tour <- function(basis,
                         manip_var,
                         theta   = NULL,
                         phi_min = 0L,
                         phi_max = .5 * pi,
                         angle   = .05,
                         ...) {
-  if (missing(manip_var)) stop("Required 'manip_var' is missing.")
-  if (!is.matrix(basis)) basis <- as.matrix(basis)
-  xArgs <- list(...) ## Terminate args meant for `render_()` also passed in `play_manual_tour()`.
-  
-  .theta <- theta
-  if (is.null(.theta)) {
-    .theta <- atan(basis[manip_var, 2L] / basis[manip_var, 1L])
+  ## Assumptions
+  basis <- as.matrix(basis)
+  if(length(manip_var) != 1 | manip_var < 1 | manip_var > nrow(basis))
+    stop("manip_var expected as a single integer between 1 and nrow(basis).")
+  if(spinifex::is_orthonormal(basis) == FALSE){
+    warning("Basis was not orthonormal. Coereced to othronormal with tourr::orthonormalise(basis).")
+    basis <- tourr::orthonormalise(basis)
   }
+  
+  ## Initalize
+  p <- nrow(basis)
+  d <- 2L ## d fixed to 2 atm.
   phi_start <- acos(sqrt(basis[manip_var, 1L]^2L + basis[manip_var, 2L]^2L))
   stopifnot(phi_min <= phi_start & phi_max >= phi_start)
+  xArgs <- list(...) ## Terminate args meant for `render_()` also passed in `play_manual_tour()`.
+  .theta <- theta
+  if (is.null(.theta))
+    .theta <- atan(basis[manip_var, 2L] / basis[manip_var, 1L])
   
-  ## Find the values of phi for each 'leg' (direction of motion)
-  phi_segment  <- function(start, end) {
+  ## Find the values of phi for each 'leg'/walk (direction of motion)
+  phi_segment  <- function(start, end){
+    ## Initalize
     mvar_xsign <- -sign(basis[manip_var, 1L])
     start      <- mvar_xsign * (start - phi_start)
     end        <- mvar_xsign * (end   - phi_start)
     dist       <- abs(end - start)
     remainder  <- dist %% angle
     sign       <- ifelse(end > start, 1L, -1L)
-    
+    ## Define segments
     segment <- seq(from = start, to = end - remainder, by = sign * angle)
-    ## If Add remaining partial step less than a full step to the end
-    if (remainder != 0L) segment <- c(segment, end) 
-    
+    ## Add remaining partial step to the end if needed.
+    if (remainder != 0L) segment <- c(segment, end)
+    ## Return
     segment
   }
   
+  ## Find the phi values for the animation frames
   phi_path <- c(phi_segment(start = phi_start, end = phi_min),
                 phi_segment(start = phi_min,   end = phi_max),
                 phi_segment(start = phi_max,   end = phi_start))
   
   ## Make projected basis array
   n_frames <- length(phi_path)
-  i_s  <- 1L:n_frames
-  p    <- nrow(basis)
-  d    <- ncol(basis)
   m_sp <- create_manip_space(basis = basis, manip_var = manip_var)
-  basis_set <- array(NA, dim = c(p, d, n_frames))
-  for (i in i_s) {
-    thisProj <- 
+  tour_array <- array(NA, dim = c(p, d, n_frames))
+  for(i in 1L:n_frames){
+    thisProj <-
       rotate_manip_space(manip_space = m_sp, theta = .theta, phi = phi_path[i])
-    basis_set[,, i] <- thisProj[, 1L:d]
+    tour_array[,, i] <- thisProj[, 1L:2L]
   }
+  attr(tour_array, "manip_var") <- manip_var
   
-  attr(basis_set, "manip_var") <- manip_var
-  
-  basis_set
+  ## Return
+  tour_array
 }
 
+##
+## INTERMEDIATE AND FORMATING -----
+##
+
+
+### Depricate, i think this creates more confusion than it helps.
+# #' Return the manipulation space of the specified rotation
+# #'
+# #' Rotates a basis returning (p, 3) manipulation space that projects to 
+# #' `view_frame()`. Allows for interactive use rather than producing a whole tour.
+# #' 
+# #' @param basis A (p, d) orthonormal numeric matrix.
+# #' The linear combination the original variables contribute to projection space.
+# #' Defaults to NULL, generating a random basis.
+# #' @param manip_var Number of the column/dimension to rotate.
+# #' @param theta Angle, in radians, of "in-plane" rotation, on the xy plane of the 
+# #' reference frame. Required, no default.
+# #' If left NULL, will initialize the radial angle of the `manip_var`.
+# #' @param phi Angle, in radians, of the "out-of-plane" rotation, 
+# #' the z-axis of the reference frame. Required, no default.
+# #' @return (p, 2) matrix of the rotated basis.
+# #' @import tourr
+# #' @export
+# #' @examples
+# #' ## PCA basis with no rotation
+# #' dat <- wine[, 2:14]
+# #' bas <- basis_pca(dat)
+# #' mv  <- manip_var_pca(dat)
+# #' rotate_basis(bas, mv)
+# #' 
+# #' ## Rotate random 
+# #' rtheta <- runif(1, 0, 2 * pi)
+# #' rphi   <- runif(1, 0, 2 * pi)
+# #' rotate_basis(basis = bas, manip_var = mv, rtheta, rphi)
+# rotate_basis <- function(basis = NULL,
+#                          manip_var,
+#                          theta = 0L,
+#                          phi = 0L){
+#   m_sp <- create_manip_space(basis, manip_var)
+#   rotate_manip_space(manip_space = m_sp, theta, phi)[, 1L:ncol(basis)]
+# }
+
