@@ -16,7 +16,7 @@
 #'   \item [run_app()], running `run_app("intro")` will open an introductory `shiny` app demonstrating radial tours.
 #'   \item [play_manual_tour()], performs a manual tour, returning a `plotly` animate by default.
 #'   \item [play_tour_path()], turns a tour path into an animation, returning a `plotly` object by default.
-#'   \item [view_basis()], plot a basis set on a reference axis.
+#'   \item [view_frame()], plot a basis set on a reference axis.
 #'   \item [view_manip_space()], plot a manipulation space highlighting the manip var.
 #' }
 #'
@@ -27,13 +27,10 @@
 "_PACKAGE"
 
 # Manual tour globals:
-globalVariables(c("col",
-                  "pch",
-                  "phi_min",
+globalVariables(c("phi_min",
                   "phi_max",
                   "manip_col",
-                  "manip_type",
-                  "n_slides",
+                  "n_frames",
                   "theta",
                   "angle")
 )
@@ -44,6 +41,6 @@ globalVariables(c("x",
                   "z",
                   "xend",
                   "yend",
-                  "lab",
-                  "slide")
+                  "label",
+                  "frame")
 )
